==> fyreonlib-0.2.9-sources.jar: com/vrs/android/fyreon/adapters/CommentUserDetailListAdapter.java <==
package com.vrs.android.fyreon.adapters;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;

import com.nostra13.universalimageloader.core.DisplayImageOptions;
import com.nostra13.universalimageloader.core.ImageLoader;
import com.vrs.android.fyreon.R;
import com.vrs.android.fyreon.model.UserDetail;
import com.vrs.android.fyreon.utils.AppConstants;
import com.vrs.android.fyreon.utils.logger.Logger;
import com.vrs.android.fyreon.widgets.CircularImageView;
import com.vrs.android.fyreon.widgets.VRSRobotoTextView;

import java.util.ArrayList;
import java.util.List;

/**
 * Package Name : com.vrs.android.fyreon.adapters
 * Created by vrsuser on 21/4/15.
 * Time : 12:11 PM
 * Project : fyreon-library-android
 * Modified : 21 12 11
 */
public class CommentUserDetailListAdapter extends ArrayAdapter<UserDetail> {

    static final String LOG_TAG = CommentUserDetailListAdapter.class.getSimpleName();
    private static final Logger logger = new Logger(true, LOG_TAG);

    Context mContext;
    LayoutInflater mInflater = null;
    List<UserDetail> dataList = new ArrayList<UserDetail>();
    DisplayImageOptions displayOptions;

    public CommentUserDetailListAdapter(Context context, int resource, List<UserDetail> objects) {
        super(context, resource, objects);
        this.mContext = context;
        this.dataList = objects;
        displayOptions = new DisplayImageOptions.Builder().showImageOnLoading(R.drawable.default_user_icon).showImageForEmptyUri(R.drawable.default_user_icon).showImageOnFail(R.drawable.default_user_icon).cacheInMemory(true).cacheOnDisk(true).build();

    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder holder = new ViewHolder();
        View layoutView = convertView;

        mInflater = (LayoutInflater) mContext
                .getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        layoutView = mInflater.inflate(R.layout.list_user_detail_cell, null, false);
        holder.ivProfileIcon = (CircularImageView) layoutView.findViewById(R.id.iv_profile_icon);
        holder.txtName = (VRSRobotoTextView) layoutView.findViewById(R.id.txt_user_name);
        holder.ivSocialIcon = (CircularImageView) layoutView.findViewById(R.id
                .comment_list_item_iv_social_icon);

        UserDetail detail = dataList.get(position);

        holder.txtName.setText(detail.getUserName());
//        Picasso.with(mContext).load(detail.getIconUrl()).placeholder(R.drawable.default_user_icon).error(R.drawable.default_user_icon).into(holder.ivProfileIcon);
        ImageLoader.getInstance().displayImage(detail.getIconUrl(), holder.ivProfileIcon,
                displayOptions);
        if (detail.getSocialTypes().equals(AppConstants.SOCIAL_TYPES_FACEBOOK)) {
            holder.ivSocialIcon.setImageResource(R.drawable.facebook);
        } else if (detail.getSocialTypes().equals(AppConstants.SOCIAL_TYPES_TWITTER)) {
            holder.ivSocialIcon.setImageResource(R.drawable.twitter_social_ic);
        } else if (detail.getSocialTypes().equals(AppConstants.SOCIAL_TYPES_GPLUS)) {
            holder.ivSocialIcon.setImageResource(R.drawable.google_social_ic);
        } else {
            holder.ivSocialIcon.setImageResource(R.drawable.ic_fyreon_icon);
//                Picasso.with(mContext).load(commentDataList.getIcons()).placeholder(R.drawable.default_user_icon).into(holder.ivProfileIcon);
        }


        return layoutView;
    }

    private class ViewHolder {
        public VRSRobotoTextView txtName;
        public ImageView ivProfileIcon, ivSocialIcon;
    }
}

==> fyreonlib-0.3.0-sources.jar: com/vrs/android/fyreon/adapters/CommentUserDetailListAdapter.java <==
package com.vrs.android.fyreon.adapters;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.nostra13.universalimageloader.core.DisplayImageOptions;
import com.nostra13.universalimageloader.core.ImageLoader;
import com.vrs.android.fyreon.R;
import com.vrs.android.fyreon.model.UserDetail;
import com.vrs.android.fyreon.utils.AppConstants;
import com.vrs.android.fyreon.utils.logger.Logger;
import com.vrs.android.fyreon.widgets.CircularImageView;

import java.util.ArrayList;
import java.util.List;

/**
 * Package Name : com.vrs.android.fyreon.adapters
 * Created by vrsuser on 21/4/15.
 * Time : 12:11 PM
 * Project : fyreon-library-android
 * Modified : 21 12 11
 */
public class CommentUserDetailListAdapter extends ArrayAdapter<UserDetail> {

    static final String LOG_TAG = CommentUserDetailListAdapter.class.getSimpleName();
    private static final Logger logger = new Logger(true, LOG_TAG);

    Context mContext;
    LayoutInflater mInflater = null;
    List<UserDetail> dataList = new ArrayList<UserDetail>();
    DisplayImageOptions displayOptions;

    public CommentUserDetailListAdapter(Context context, int resource, List<UserDetail> objects) {
        super(context, resource, objects);
        this.mContext = context;
        this.dataList = objects;
        displayOptions = new DisplayImageOptions.Builder().showImageOnLoading(R.drawable.default_user_icon).showImageForEmptyUri(R.drawable.default_user_icon).showImageOnFail(R.drawable.default_user_icon).cacheInMemory(true).cacheOnDisk(true).build();

    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder holder = new ViewHolder();
        View layoutView = convertView;

        mInflater = (LayoutInflater) mContext
                .getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        layoutView = mInflater.inflate(R.layout.list_user_detail_cell, null, false);
        holder.ivProfileIcon = (CircularImageView) layoutView.findViewById(R.id.iv_profile_icon);
        holder.txtName = (TextView) layoutView.findViewById(R.id.txt_user_name);
        holder.ivSocialIcon = (CircularImageView) layoutView.findViewById(R.id
                .comment_list_item_iv_social_icon);

        UserDetail detail = dataList.get(position);

        holder.txtName.setText(detail.getUserName());
//        Picasso.with(mContext).load(detail.getIconUrl()).placeholder(R.drawable.default_user_icon).error(R.drawable.default_user_icon).into(holder.ivProfileIcon);
        ImageLoader.getInstance().displayImage(detail.getIconUrl(), holder.ivProfileIcon,
                displayOptions);
        if (detail.getSocialTypes().equals(AppConstants.SOCIAL_TYPES_FACEBOOK)) {
            holder.ivSocialIcon.setImageResource(R.drawable.facebook);
        } else if (detail.getSocialTypes().equals(AppConstants.SOCIAL_TYPES_TWITTER)) {
            holder.ivSocialIcon.setImageResource(R.drawable.twitter_social_ic);
        } else if (detail.getSocialTypes().equals(AppConstants.SOCIAL_TYPES_GPLUS)) {
            holder.ivSocialIcon.setImageResource(R.drawable.google_social_ic);
        } else {
            holder.ivSocialIcon.setImageResource(R.drawable.ic_fyreon_icon);
//                Picasso.with(mContext).load(commentDataList.getIcons()).placeholder(R.drawable.default_user_icon).into(holder.ivProfileIcon);
        }


        return layoutView;
    }

    private class ViewHolder {
        public TextView txtName;
        public ImageView ivProfileIcon, ivSocialIcon;
    }
}
